@@ -159,6 +159,7 @@ fn filter_input_attrs(attr: &Attribute) -> bool {
         || attr.path.is_ident("cfg_attr")
         || attr.path.is_ident("serde")
         || attr.path.is_ident("non_exhaustive")
+        || attr.path.is_ident("allow")
 }
 
 fn impl_outgoing_with_incoming_self(input: &DeriveInput, ruma_serde: &TokenStream) -> TokenStream {
@@ -258,9 +259,12 @@ fn strip_lifetimes(field_type: &mut Type) -> bool {
                     if last_seg.ident == "str" {
                         // &str -> String
                         Some(parse_quote! { ::std::string::String })
-                    } else if last_seg.ident == "DeviceId"
+                    } else if last_seg.ident == "ClientSecret"
+                        || last_seg.ident == "DeviceId"
                         || last_seg.ident == "ServerName"
+                        || last_seg.ident == "SessionId"
                         || last_seg.ident == "RawJsonValue"
+                        || last_seg.ident == "RoomName"
                     {
                         // The identifiers that need to be boxed `Box<T>` since they are DST's.
                         Some(parse_quote! { ::std::boxed::Box<#path> })
